@@ -1,5 +1,5 @@
 __version__ = "0.1.0"
 
-from .parsers import BaseParser
+from . import parsers
 from .command import Command
 from .errors import ArgumentError
